@@ -1,10 +1,14 @@
 /*
-   (c) Copyright 2000  convergence integrated media GmbH.
+   (c) Copyright 2001-2007  The DirectFB Organization (directfb.org)
+   (c) Copyright 2000-2004  Convergence (integrated media) GmbH
+
    All rights reserved.
 
-   Written by Denis Oliver Kropp <dok@convergence.de>,
-              Andreas Hundt <andi@convergence.de> and
-              Sven Neumann <sven@convergence.de>. 
+   Written by Denis Oliver Kropp <dok@directfb.org>,
+              Andreas Hundt <andi@fischlustig.de>,
+              Sven Neumann <neo@directfb.org>,
+              Ville Syrjälä <syrjala@sci.fi> and
+              Claudio Ciccani <klan@users.sf.net>.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -25,10 +29,10 @@
 #ifndef __DIRECTFB_VERSION_H__
 #define __DIRECTFB_VERSION_H__
 
-#define DIRECTFB_MAJOR_VERSION  (0)
-#define DIRECTFB_MINOR_VERSION  (9)
+#define DIRECTFB_MAJOR_VERSION  (1)
+#define DIRECTFB_MINOR_VERSION  (2)
 #define DIRECTFB_MICRO_VERSION  (8)
-#define DIRECTFB_BINARY_AGE     (0)
+#define DIRECTFB_BINARY_AGE     (8)
 #define DIRECTFB_INTERFACE_AGE  (0)
 
 #endif /* __DIRECTFB_VERSION_H__ */
